@@ -8,6 +8,9 @@ pub struct EmailClientConfig {
     #[structopt(long, env = "LS_EMAIL_CLIENT_TYPE", default_value = "full")]
     pub client_type: EmailClientType,
 
+    #[structopt(long, env = "LS_EMAIL_CLIENT_TIMEOUT_SECONDS", default_value = "60")]
+    pub client_timeout_seconds: u64,
+
     #[structopt(long, env = "LS_EMAIL_SERVER_PORT", default_value = "1025")]
     pub server_port: u16,
 
